@@ -4,6 +4,7 @@
  * Copyright (C) 2010 Creytiv.com
  */
 
+struct re;
 
 enum {
 #ifndef FD_READ
@@ -44,10 +45,15 @@ int   re_main(re_signal_h *signalh);
 void  re_cancel(void);
 int   re_debug(struct re_printf *pf, void *unused);
 
+int  re_alloc(struct re **rep);
+int  re_thread_attach(struct re *re);
+void re_thread_detach(void);
+
 int  re_thread_init(void);
 void re_thread_close(void);
 void re_thread_enter(void);
 void re_thread_leave(void);
+int  re_thread_check(void);
 
 void re_set_mutex(void *mutexp);
 
